pub struct RoomRelationsResponseTemplate {
pub chunk: Vec<Raw<AnyTimelineEvent>>,
pub next_batch: Option<String>,
pub prev_batch: Option<String>,
pub recursion_depth: Option<u32>,
}Available on (crate features
testing) and non-target_family=wasm only.Expand description
A response to a RoomRelationsEndpoint query.
Fields
chunk: Vec<Raw<AnyTimelineEvent>>The set of timeline events returned by this query.
next_batch: Option<String>An opaque string representing a pagination token, which semantics depend on the direction used in the request.
prev_batch: Option<String>An opaque string representing a pagination token, which semantics depend on the direction used in the request.
recursion_depth: Option<u32>If recurse was set on the request, the depth to which the server
recursed.
If recurse was not set, this field must be absent.
Implementations
Sourceimpl RoomRelationsResponseTemplate
impl RoomRelationsResponseTemplate
Sourcepub fn events(self, chunk: Vec<impl Into<Raw<AnyTimelineEvent>>>) -> Self
pub fn events(self, chunk: Vec<impl Into<Raw<AnyTimelineEvent>>>) -> Self
Fill the events returned as part of this response.
Sourcepub fn next_batch(self, token: impl Into<String>) -> Self
pub fn next_batch(self, token: impl Into<String>) -> Self
Fill the next_batch token returned as part of this response.
Sourcepub fn prev_batch(self, token: impl Into<String>) -> Self
pub fn prev_batch(self, token: impl Into<String>) -> Self
Fill the prev_batch token returned as part of this response.
Sourcepub fn recursion_depth(self, depth: u32) -> Self
pub fn recursion_depth(self, depth: u32) -> Self
Fill the recursion depth returned in this response.